@@ -554,7 +554,7 @@ def mcp():
 def mcp_server():
     """Runs the Starbase MCP server (for use by Claude tools)."""
     try:
-        from src.starbase.mcp_server import main as mcp_main
+        from starbase.mcp_server import main as mcp_main
         mcp_main()
     except ImportError:
         if console:
@@ -580,30 +580,40 @@ def update():
     pipx_path = shutil.which("pipx")
     if pipx_path:
         try:
-            # First uninstall existing version
-            console.print("[dim]Uninstalling current version...[/dim]")
-            subprocess.run([pipx_path, "uninstall", "starbase-code"], capture_output=True, text=True)
+            # Use pipx upgrade instead of uninstall/install
+            console.print("[dim]Upgrading to latest version from PyPI...[/dim]")
+            result = subprocess.run([pipx_path, "upgrade", "starbase-code"], capture_output=True, text=True)
             
-            # Install latest from PyPI
-            console.print("[dim]Installing latest version from PyPI...[/dim]")
-            result = subprocess.run([pipx_path, "install", "starbase-code"], capture_output=True, text=True)
-            
-            if result.returncode == 0:
-                # Run MCP installer to ensure Claude Desktop integration
+            if result.returncode == 0 or "already has" in result.stdout:
+                # Ensure Claude Desktop integration still works
                 console.print("\n[cyan]🔗 Ensuring Claude Desktop integration...[/cyan]")
-                installer = MCPInstaller(project_root_path=Path.cwd())
-                installer._ensure_standard_path_access("starbase")
+                
+                # Only create symlink if Claude Desktop exists and symlink is needed
+                if Path("/Applications/Claude.app").exists():
+                    starbase_path = shutil.which("starbase")
+                    if starbase_path and not starbase_path.startswith("/usr/local/bin"):
+                        # Need to create symlink for Claude Desktop
+                        symlink_path = Path("/usr/local/bin/starbase")
+                        if not symlink_path.exists() or not symlink_path.is_symlink():
+                            console.print("[yellow]Creating symlink for Claude Desktop (may require password)...[/yellow]")
+                            subprocess.run(["sudo", "ln", "-sf", starbase_path, str(symlink_path)])
+                
+                # Update configs
+                installer = MCPInstaller()
                 installer._update_claude_config()
                 installer._update_claude_code_config()
                 
                 console.print("\n[bold green]✅ Starbase updated successfully![/bold green]")
-                console.print("[dim]Restart your terminal or Claude Desktop to use the new version.[/dim]")
+                if "already has" in result.stdout:
+                    console.print("[dim]You already have the latest version.[/dim]")
+                else:
+                    console.print("[dim]Restart your terminal or Claude Desktop to use the new version.[/dim]")
             else:
                 console.print(f"[red]❌ Update failed: {result.stderr}[/red]")
-                console.print("[yellow]Try running: pipx install starbase-code[/yellow]")
+                console.print("[yellow]Try running: pipx upgrade starbase-code[/yellow]")
         except Exception as e:
             console.print(f"[red]❌ Update error: {e}[/red]")
-            console.print("[yellow]Try running: pipx install starbase-code[/yellow]")
+            console.print("[yellow]Try running: pipx upgrade starbase-code[/yellow]")
     else:
         console.print("[red]❌ pipx not found. Install pipx first:[/red]")
         console.print("  macOS: [cyan]brew install pipx[/cyan]")
@@ -1240,8 +1250,8 @@ def index():
                     all_files = list(item.rglob('*'))
                     code_files = [f for f in all_files if f.is_file() and f.suffix in {'.py', '.js', '.ts', '.jsx', '.tsx', '.json', '.yaml', '.yml'}]
                     
-                    # Generate simple description
-                    description = generate_smart_description(item)
+                    # Generate smart description using LLM
+                    description = generate_smart_description(item, None, manager, console)
                     
                     db.insert({
                         'name': item.name,
@@ -1308,7 +1318,7 @@ def refresh_descriptions():
             if project_path.exists() and project_path.is_dir():
                 console.print(f"\n[dim]Analyzing {entry['name']}...[/dim]")
                 try:
-                    new_desc = generate_smart_description(project_path)
+                    new_desc = generate_smart_description(project_path, None, manager, console)
                     
                     # Always update - LLM might generate better description
                     Query = tinydb.Query()
