@@ -168,9 +168,119 @@ def find_related_files(py_file: Path) -> List[str]:
     return related[:5]  # Limit display
 
 
-def generate_smart_description(project_path: Path, entry_points: List[Dict] = None) -> str:
-    """Generate a simple description by analyzing the code"""
-    # Simple fallback - just describe what we extracted
+def generate_smart_description(project_path: Path, entry_points: List[Dict] = None, manager=None, console=None) -> str:
+    """Generate intelligent description by analyzing code with LLM"""
+    try:
+        # Try to use LLM for smart description
+        if manager:
+            # Import here to avoid circular dependency
+            import sys
+            import os
+            parent_dir = Path(__file__).parent.parent
+            if str(parent_dir) not in sys.path:
+                sys.path.insert(0, str(parent_dir))
+            
+            # Import get_llm from starbase
+            try:
+                from starbase import get_llm
+            except ImportError:
+                # Try alternate import for installed package
+                from starbase.cli import get_llm
+            
+            # Collect relevant files to analyze
+            files_to_analyze = []
+            
+            # Common code file patterns
+            code_patterns = ['*.py', '*.js', '*.ts', '*.jsx', '*.tsx', '*.java', '*.go', '*.rs', 
+                           '*.cpp', '*.c', '*.h', '*.cs', '*.rb', '*.php', '*.swift', '*.kt']
+            
+            # Documentation patterns
+            doc_patterns = ['README*', '*.md', '*.txt', 'LICENSE*', 'CHANGELOG*']
+            
+            # Collect files
+            for pattern in code_patterns + doc_patterns:
+                files_to_analyze.extend(project_path.glob(pattern))
+                # Also check one level deep for organized projects
+                files_to_analyze.extend(project_path.glob(f"*/{pattern}"))
+            
+            # Filter out unwanted directories
+            skip_dirs = {'venv', '.venv', 'env', '.env', 'node_modules', '__pycache__', 
+                        '.git', 'dist', 'build', '.pytest_cache', '.tox', 'htmlcov',
+                        'site-packages', 'migrations', '.idea', '.vscode'}
+            
+            files_to_analyze = [
+                f for f in files_to_analyze 
+                if f.is_file() and not any(skip in f.parts for skip in skip_dirs)
+            ]
+            
+            # Limit to reasonable number of files and size
+            content_parts = []
+            total_chars = 0
+            max_total_chars = 15000  # Limit total content
+            
+            # Prioritize README and main files
+            priority_files = sorted(files_to_analyze, key=lambda f: (
+                0 if 'README' in f.name.upper() else
+                1 if f.name in ['main.py', 'app.py', 'index.js', 'index.ts'] else
+                2 if entry_points and any(str(f) == str(ep.get('file', '')) for ep in entry_points) else
+                3
+            ))
+            
+            for file in priority_files[:20]:  # Max 20 files
+                try:
+                    if file.stat().st_size < 50000:  # Under 50KB per file
+                        content = file.read_text(errors='ignore')
+                        # Take more content from important files
+                        char_limit = 3000 if 'README' in file.name.upper() else 1500
+                        truncated = content[:char_limit]
+                        if len(content) > char_limit:
+                            truncated += "\n... (truncated)"
+                        
+                        content_parts.append(f"\n--- File: {file.name} ---\n{truncated}\n")
+                        total_chars += len(truncated)
+                        
+                        if total_chars > max_total_chars:
+                            break
+                except Exception:
+                    continue  # Skip files that can't be read
+            
+            if content_parts:
+                # Get LLM instance
+                llm = get_llm()
+                
+                # Create prompt
+                prompt = """Analyze this code and write a concise 1-2 sentence description.
+Focus on: what it does, main purpose, key algorithms or patterns, and technologies/frameworks used.
+Be specific - mention actual function names, libraries, or algorithms if notable.
+Do NOT just say "Python script" or "code package" - explain what it actually does.
+
+Code files:
+{}
+
+Write a clear, specific description:""".format(''.join(content_parts))
+                
+                # Get LLM response
+                if console:
+                    console.print("[dim]Analyzing code with LLM...[/dim]")
+                
+                response = llm.invoke(prompt)
+                description = response.content.strip() if hasattr(response, 'content') else str(response).strip()
+                
+                # Clean up the description
+                description = description.replace('\n', ' ').strip()
+                
+                # Ensure it's not too long
+                if len(description) > 200:
+                    description = description[:197] + "..."
+                
+                return description
+                
+    except Exception as e:
+        # Fallback if LLM fails
+        if console:
+            console.print(f"[dim]LLM analysis failed: {e}[/dim]")
+    
+    # Fallback to basic description
     if entry_points and len(entry_points) == 1:
         file_path = entry_points[0]['file']
         return f"Extracted {file_path.name} - Python script"
@@ -294,8 +404,8 @@ def do_extraction(entry_points: List[Dict], source_path: Path, include_deps: boo
     
     # Update catalog
     if extracted_files:
-        # Generate simple description
-        description = generate_smart_description(target_dir, entry_points)
+        # Generate smart description using LLM
+        description = generate_smart_description(target_dir, entry_points, manager, console)
         
         catalog_entry = {
             'name': extract_name,
