@@ -52,18 +52,14 @@ class MCPInstaller:
             try:
                 # Check if starbase is installed via pipx
                 result = subprocess.run([pipx_path, "list"], capture_output=True, text=True)
-                if "starbase" in result.stdout:
+                if "starbase-code" in result.stdout:
                     console.print("[yellow]Found existing pipx installation. Removing...[/yellow]")
-                    subprocess.run([pipx_path, "uninstall", "starbase"], capture_output=True)
+                    subprocess.run([pipx_path, "uninstall", "starbase-code"], capture_output=True)
                     console.print("[green]✓ Removed old pipx installation[/green]")
             except:
                 pass  # Ignore errors during cleanup
         
-        # Check for symlinks in standard locations
-        standard_paths = ["/usr/local/bin/starbase", "/opt/homebrew/bin/starbase"]
-        for path in standard_paths:
-            if Path(path).exists():
-                console.print(f"[yellow]Found old symlink at {path}. This may require sudo to remove.[/yellow]")
+        # Don't mention symlinks here - we'll handle them after installation
     
     def _ensure_standard_path_access(self, package_name: str):
         """Ensure the command is accessible in standard paths for Claude Desktop."""
@@ -214,108 +210,31 @@ class MCPInstaller:
 
     def _install_package_globally(self, package_name: str, method: str = "auto") -> bool:
         """
-        Automated, multi-step installation of the package from the local project source.
-        Tries pipx -> sudo pipx -> pip, with user prompts for elevated permissions.
+        Install starbase-code from PyPI using pipx.
         """
-        package_path = self.project_root_path
+        console.print(f"\n[cyan]Installing '{package_name}' from PyPI...[/cyan]")
 
-        console.print(f"\n[cyan]Preparing '{package_name}' for global installation from {package_path}...[/cyan]")
-        if not self._prepare_package_for_global_install(package_path, package_name):
-            return False
-
-        console.print(f"\n[cyan]Building package with PDM...[/cyan]")
-        original_dir = Path.cwd()
-        os.chdir(package_path)
-
-        try:
-            # Build the package
-            subprocess.run(["pdm", "build"], check=True, capture_output=True, text=True)
-            
-            dist_dir = package_path / "dist"
-            wheels = list(dist_dir.glob("*.whl"))
-            if not wheels:
-                console.print("[red]❌ No wheel file found after PDM build.[/red]")
-                return False
-            
-            wheel_path = wheels[-1]
-            console.print(f"\n[green]✓ Package built successfully: {wheel_path.name}[/green]")
-
-            # --- Start of the new automated installation logic ---
-
-            # 1. Try pipx
-            pipx_path = shutil.which("pipx")
-            if pipx_path:
-                console.print("\n[cyan]🚀 Phase 1: `pipx` found. Attempting recommended installation...[/cyan]")
-                try:
-                    pipx_command = [pipx_path, "install", "--force", str(wheel_path)]
-                    subprocess.run(pipx_command, check=True, capture_output=True, text=True)
-                    console.print("[bold green]✅ Success! Starbase installed globally via pipx.[/bold green]")
-                    console.print("[dim]Please restart your terminal for changes to take effect.[/dim]")
-                    return True
-                except subprocess.CalledProcessError as e:
-                    if "permission" in e.stderr.lower() or "denied" in e.stderr.lower():
-                        console.print("[yellow]⚠️ pipx installation failed due to a permission error.[/yellow]")
-                        # 2. Try sudo pipx
-                        if Confirm.ask("[bold yellow]Do you want to attempt the installation again with administrator privileges (sudo)?[/bold yellow]"):
-                            console.print("\n[cyan]🚀 Phase 2: Attempting installation with `sudo pipx`...[/cyan]")
-                            try:
-                                sudo_pipx_command = ["sudo", pipx_path, "install", "--force", str(wheel_path)]
-                                console.print(f"[dim]Running command: {' '.join(sudo_pipx_command)}[/dim]")
-                                console.print("[dim]Your OS may ask for your password.[/dim]")
-                                subprocess.run(sudo_pipx_command, check=True, capture_output=True, text=True)
-                                console.print("[bold green]✅ Success! Starbase installed globally via sudo pipx.[/bold green]")
-                                console.print("[dim]Please restart your terminal for changes to take effect.[/dim]")
-                                return True
-                            except subprocess.CalledProcessError as sudo_e:
-                                console.print(f"[red]❌ `sudo pipx` failed.[/red]")
-                                # Fall through to pip
-                    else:
-                        console.print(f"[red]❌ `pipx` failed for a reason other than permissions.[/red]")
-                        # Fall through to pip
-            else:
-                console.print("[yellow]⚠️ Recommended tool `pipx` not found.[/yellow]")
-                # Offer to install pipx (informational, not executed)
-                if Confirm.ask("[bold yellow]Do you want to see instructions for installing pipx?[/bold yellow]"):
-                     console.print("\nTo install pipx, use one of the following commands:")
-                     console.print("  - On macOS (with Homebrew): [cyan]brew install pipx[/cyan]")
-                     console.print("  - On Linux (Debian/Ubuntu): [cyan]sudo apt install pipx[/cyan]")
-                     console.print("  - With Python's pip:       [cyan]python3 -m pip install --user pipx && python3 -m pipx ensurepath[/cyan]")
-                     console.print("After installing, please re-run the starbase command.")
-                     return False # End the process here to let user install pipx
-
-            # 3. Fallback to pip
-            console.print("\n[cyan]🚀 Phase 3: Falling back to `pip` for installation...[/cyan]")
+        # 1. Try pipx
+        pipx_path = shutil.which("pipx")
+        if pipx_path:
+            console.print("\n[cyan]🚀 Installing from PyPI with pipx...[/cyan]")
             try:
-                pip_command = [
-                    sys.executable, "-m", "pip", "install", "--user",
-                    "--force-reinstall", "--break-system-packages", str(wheel_path.absolute())
-                ]
-                subprocess.run(pip_command, check=True, capture_output=True, text=True)
-                console.print("[bold green]✅ Success! Starbase installed globally via pip.[/bold green]")
+                # Install from PyPI
+                pipx_command = [pipx_path, "install", "--force", "starbase-code"]
+                subprocess.run(pipx_command, check=True, capture_output=True, text=True)
+                console.print("[bold green]✅ Success! Starbase installed globally via pipx.[/bold green]")
                 console.print("[dim]Please restart your terminal for changes to take effect.[/dim]")
                 return True
             except subprocess.CalledProcessError as e:
-                console.print(f"[red]❌ `pip` installation failed.[/red]")
-                console.print(f"[red]STDERR: {e.stderr}[/red]")
-
-            # 4. Final Failure
-            console.print("\n[bold red]❌ All automated installation methods have failed.[/bold red]")
-            console.print("You can try to install the package manually. Please run one of the following commands:")
-            console.print(f"  - Recommended: [cyan]pipx install --force {wheel_path.absolute()}[/cyan]")
-            console.print(f"  - Alternative: [cyan]pip install --user --force-reinstall --break-system-packages {wheel_path.absolute()}[/cyan]")
+                console.print(f"[red]❌ pipx installation failed: {e.stderr}[/red]")
+                return False
+        else:
+            console.print("[red]❌ pipx not found. Install pipx first:[/red]")
+            console.print("  macOS: [cyan]brew install pipx[/cyan]")
+            console.print("  Linux: [cyan]sudo apt install pipx[/cyan]")
+            console.print("  Or:    [cyan]python3 -m pip install --user pipx[/cyan]")
             return False
 
-        except subprocess.CalledProcessError as e:
-            console.print(f"[red]Build failed:[/red]")
-            console.print(f"[red]STDOUT: {e.stdout}[/red]")
-            console.print(f"[red]STDERR: {e.stderr}[/red]")
-            return False
-        except Exception as e:
-            console.print(f"[red]An unexpected error occurred during build: {e}[/red]")
-            return False
-        finally:
-            os.chdir(original_dir)
-
     def configure_project_mcp(self, project_path: Optional[Path] = None) -> bool:
         """Configure starbase MCP server for a specific Claude Code project."""
         project_path = Path(project_path) if project_path else Path.cwd()
